from django.http import HttpResponse, Http404, HttpResponseForbidden, HttpResponseRedirect
from django.shortcuts import render_to_response, get_object_or_404, redirect
from django.contrib.auth.decorators import login_required
from django.template import RequestContext
from django.template.loader import render_to_string
from django.contrib.syndication.views import Feed
from django.contrib.auth.models import User, Group
from django.conf import settings
from django.contrib.auth.views import login as auth_login, logout as auth_logout
from django.views.generic.list import ListView

from  datetime  import datetime, timedelta
import logging

try:
    import simplejson
except ImportError:
    from django.utils import simplejson

from dinette.models import Ftopics, Category, Reply, DinetteUserProfile
from dinette.forms import  FtopicForm, ReplyForm


#Create module logger
#several logging configurations are configured in the models
mlogger = logging.getLogger(__name__)


json_mimetype = 'application/javascript'


def index_page(request):
    #groups which this user has access
    if request.user.is_authenticated():
        groups = [group for group in request.user.groups.all()] + [group for group in Group.objects.filter(name="general")]
    else:
        #we are treating user who have not loggedin belongs to general group
        groups = Group.objects.filter(name="general")
    #logic which decide which forum does this user have access to
    forums = []
    for group in groups:
        forums.extend([each for each in group.can_access_forums.all()])
    forums = set(forums)
    forums = sorted(forums, cmp=lambda x, y: y.ordering - x.ordering)
    totaltopics = Ftopics.objects.count()
    totalposts = totaltopics + Reply.objects.count()
    totalusers = User.objects.count()
    now = datetime.now()
    users_online = DinetteUserProfile.objects.filter(last_activity__gte =  now - timedelta(seconds = 900)).count() + 1#The current user is always online. :)
    last_registered_user = User.objects.order_by('-date_joined')[0]
    payload = {'users_online':users_online, 'forums_list':forums, 'totaltopics':totaltopics,
               'totalposts':totalposts, 'totalusers':totalusers, 'last_registered_user':last_registered_user}
    return render_to_response("dinette/mainindex.html", payload,RequestContext(request))


def category_details(request, categoryslug,  pageno=1) :
    #build a form for posting topics
    topicform = FtopicForm()
    category = get_object_or_404(Category, slug=categoryslug)
    queryset = Ftopics.objects.filter(category__id__exact = category.id)
    topic_page_size = getattr(settings , "TOPIC_PAGE_SIZE", 10)
    payload = {'topicform': topicform,'category':category,'authenticated':request.user.is_authenticated(),'topic_list':queryset, "topic_page_size": topic_page_size}
    return render_to_response("dinette/category_details.html", payload, RequestContext(request))


topic_list = ListView.as_view(template_name='dinette/topiclist.html', model=Ftopics, context_object_name='topic', paginate_by=2)


def topic_detail(request, categoryslug, topic_slug , pageno = 1):
    topic = get_object_or_404(Ftopics, slug = topic_slug)
    show_moderation_items = False
    if request.user in topic.category.moderated_by.all():
        show_moderation_items = True
    #some body has viewed this topic
    topic.viewcount = topic.viewcount + 1
    topic.save()
    #we also need to display the reply form
    replylist = topic.reply_set.all()
    reply_page_size = getattr(settings , "REPLY_PAGE_SIZE", 10)
    replyform = ReplyForm()
    payload = {'topic': topic, 'replyform':replyform,'reply_list':replylist, 'show_moderation_items':show_moderation_items, "reply_page_size": reply_page_size}
    return render_to_response("dinette/topic_detail.html", payload, RequestContext(request))

@login_required
def postTopic(request) :
    mlogger.info("In post Topic page.....................")
    mlogger.debug("Type of request.user %s" % type(request.user)  )

    topic = FtopicForm(request.POST, request.FILES)

    if topic.is_valid() == False :
        d = {"is_valid":"false","response_html":topic.as_table()}
        json = simplejson.dumps(d)
        if request.FILES :
            json = "<textarea>"+simplejson.dumps(d)+"</textarea>"
        else:
            json = simplejson.dumps(d)
        return HttpResponse(json, mimetype = json_mimetype)

    #code which checks for flood control
    if (datetime.now()-request.user.get_profile().last_posttime).seconds < settings.FLOOD_TIME:
    #oh....... user trying to flood us Stop him
        d2 = {"is_valid":"flood","errormessage":"Flood control.................."}
        if request.FILES :
            json = "<textarea>"+simplejson.dumps(d2)+"</textarea>"
        else :
            json = simplejson.dumps(d2)
        return HttpResponse(json, mimetype = json_mimetype)

    ftopic = topic.save(commit=False)
    #only if there is any file
    if request.FILES :
        if(request.FILES['file'].content_type.find("image") >= 0 ) :
            ftopic.attachment_type = "image"
        else :
            ftopic.attachment_type = "text"
        ftopic.filename = request.FILES['file'].name

    ftopic.posted_by = request.user

    mlogger.debug("categoryid= %s" %request.POST['categoryid'])
    ftopic.category  = Category.objects.get(pk = request.POST['categoryid'])

    #Assigning user rank
    mlogger.debug("Assigning an user rank and last posted datetime")
    assignUserElements(request.user)
    ftopic.save()
    #autosubsribe
    ftopic.subscribers.add(request.user)

    mlogger.debug("what is the message (%s %s) " % (ftopic.message,ftopic.subject))
    payload = {'topic':ftopic}
    response_html = render_to_string('dinette/topic_detail_frag.html', payload,RequestContext(request))
    mlogger.debug("what is the response = %s " % response_html)

    d2 = {"is_valid":"true","response_html":response_html}

    #this the required for ajax file uploads
    if request.FILES :
        json = "<textarea>"+simplejson.dumps(d2)+"</textarea>"
    else :
        json = simplejson.dumps(d2)
    return HttpResponse(json, mimetype = json_mimetype)

@login_required
def postReply(request):
    mlogger.info("in post reply.................")
    freply = ReplyForm(request.POST,request.FILES)

    if freply.is_valid() == False :
        d = {"is_valid":"false","response_html":freply.as_table()}
        json = simplejson.dumps(d)
        if request.FILES :
            json = "<textarea>"+simplejson.dumps(d)+"</textarea>"
        else:
            json = simplejson.dumps(d)
        return HttpResponse(json, mimetype = json_mimetype)



    #code which checks for flood control
    if (datetime.now() -(request.user.get_profile().last_posttime)).seconds <= settings.FLOOD_TIME:
    #oh....... user trying to flood us Stop him
        d2 = {"is_valid":"flood","errormessage":"You have posted message too recently. Please wait a while before trying again."}
        if request.FILES :
            json = "<textarea>"+simplejson.dumps(d2)+"</textarea>"
        else :
            json = simplejson.dumps(d2)
        return HttpResponse(json, mimetype = json_mimetype)


    reply = freply.save(commit=False)
     #only if there is any file
    if len(request.FILES.keys()) == 1 :
        if(request.FILES['file'].content_type.find("image") >= 0 ) :
            reply.attachment_type = "image"
        else :
            reply.attachment_type = "text"

        reply.filename = request.FILES['file'].name

    reply.posted_by = request.user
    mlogger.debug("toipcid= %s" %request.POST['topicid'])
    reply.topic = Ftopics.objects.get(pk = request.POST['topicid'])
    #Assigning user rank
    mlogger.debug("Assigning an user rank, and last posted datetime")
    assignUserElements(request.user)
    reply.save()
    payload = {'reply':reply}
    mlogger.debug("what is the replymesage = %s" %reply.message)
    response_html = render_to_string('dinette/replydetail_frag.html', payload ,RequestContext(request))
    mlogger.debug("what is the response = %s " % response_html)

    d2 = {"is_valid":"true","response_html":response_html}

    if request.FILES :
        #this the required for ajax file uploads
        json = "<textarea>"+simplejson.dumps(d2)+"</textarea>"
    else:
        json = simplejson.dumps(d2)

    return HttpResponse(json, mimetype = json_mimetype)

@login_required
def deleteReply(request, reply_id):
    resp= {"status": "1", "message": "Successfully deleted the reply"}
    try:
        reply = Reply.objects.get(pk=reply_id)
        if not (reply.posted_by == request.user or request.user in reply.topic.category.moderated_by.all()):
            return HttpResponseForbidden()
        reply.delete()
    except:
        resp["status"] = 0
        resp["message"] = "Error deleting message"
    json = simplejson.dumps(resp)
    return HttpResponse(json, mimetype = json_mimetype)

@login_required
def editReply(request, reply_id):
    reply = get_object_or_404(Reply, pk=reply_id)
    if not (reply.posted_by == request.user or request.user in reply.topic.category.moderated_by.all()):
        return HttpResponseForbidden()

    if request.POST:
        form = ReplyForm(request.POST, request.FILES, instance=reply)
        if form.is_valid():
            form.save()
            #redirect to prev page
            return HttpResponseRedirect(reply.get_url_with_fragment())
    else:
        # message should be original input, not the rendered one
        form = ReplyForm(instance=reply, initial={'message': reply.message.raw})

    return render_to_response('dinette/edit_reply.html', {'replyform': form, 'reply_id': reply_id}, context_instance=RequestContext(request))

class LatestTopicsByCategory(Feed):
    title_template = 'dinette/feeds/title.html'
    description_template = 'dinette/feeds/description.html'

    def get_object(self, whichcategory):
        mlogger.debug("Feed for category %s " % whichcategory)
        return get_object_or_404(Category, slug=whichcategory[0])

    def title(self, obj):
        return "Latest topics in category %s" % obj.name

    def link(self, obj):
        return  settings.SITE_URL

    def items(self, obj):
        return obj.ftopics_set.all()[:10]

    #construct these links by means of reverse lookup  by
    #using permalink decorator
    def item_link(self,obj):
        return  obj.get_absolute_url()

    def item_pubdate(self,obj):
        return obj.created_on


class LatestRepliesOfTopic(Feed):
    title_template = 'dinette/feeds/title.html'
    description_template = 'dinette/feeds/description.html'

    def get_object(self, whichtopic):
        mlogger.debug("Feed for category %s " % whichtopic)
        return get_object_or_404(Ftopics, slug=whichtopic[0])

    def title(self, obj):
        return "Latest replies in topic %s" % obj.subject

    def link(self, obj):
        return  settings.SITE_URL

    def items(self, obj):
        list = []
        list.insert(0,obj)
        for obj in obj.reply_set.all()[:10] :
            list.append(obj)
        return list

     #construct these links by means of reverse lookup  by
     #using permalink decorator
    def item_link(self,obj):
        return  obj.get_absolute_url()

    def item_pubdate(self,obj):
        return obj.created_on



def assignUserElements(user):
    ranks = getattr(settings, 'RANKS_NAMES_DATA')
    rank = ''
    if ranks:
        totalposts = user.ftopics_set.count() + user.reply_set.count()
        for el in ranks:
            if totalposts == el[0]:
                rank = el[1]
        if rank:
            userprofile = user.get_profile()
            userprofile.userrank = rank
            #this is the time when user posted his last post
            userprofile.last_posttime = datetime.now()
            userprofile.save()


###Moderation views###
@login_required
def moderate_topic(request, topic_id, action):
    topic = get_object_or_404(Ftopics, pk = topic_id)
    if not request.user in topic.category.moderated_by.all():
        raise Http404
    if request.method == 'POST':
        if action == 'close':
            if topic.is_closed:
                message = 'You have reopened topic %s'%topic.subject
            else:
                message = 'You have closed topic %s'%topic.subject
            topic.is_closed = not topic.is_closed
        elif action == 'announce':
            if topic.announcement_flag:
                message = '%s is no longer an announcement.' % topic.subject
            else:
                message = '%s is now an announcement.' % topic.subject
            topic.announcement_flag = not topic.announcement_flag
        elif action == 'sticky':
            if topic.is_sticky:
                message = '%s has been unstickied.' % topic.subject
            else:
                message = '%s has been stickied.' % topic.subject
            topic.is_sticky = not topic.is_sticky
        elif action == 'hide':
            if topic.is_hidden:
                message = '%s has been unhidden.' % topic.subject
            else:
                message = "%s has been hidden and won't show up any further." % topic.subject
            topic.is_hidden = not topic.is_hidden
        topic.save()
        payload = {'topic_id':topic.pk, 'message':message}
        resp = simplejson.dumps(payload)
        return HttpResponse(resp, mimetype = json_mimetype)
    else:
        return HttpResponse('This view must be called via post')

def login(request):
    return auth_login(request)

def logout(request):
    return auth_logout(request)

def user_profile(request, slug):
    user_profile = get_object_or_404(User, dinetteuserprofile__slug=slug)
    return render_to_response('dinette/user_profile.html', {}, RequestContext(request, {'user_profile': user_profile}))

@login_required
def new_topics(request):
    userprofile = request.user.get_profile()
    new_topic_list = userprofile.get_since_last_visit()
    return topic_list(request, new_topic_list, page_message = "Topics since your last visit")

def active(request):
    #Time filter = 48 hours
    days_ago_2 = datetime.now() - timedelta(days = 2)
    topics = Ftopics.objects.filter(last_reply_on__gt =  days_ago_2)
    active_topics = topics.extra(select= {"activity":"viewcount+100*num_replies"}).order_by("-activity")
    return topic_list(request, active_topics, page_message = "Most active Topics")

def unanswered(request):
    unanswered_topics = Ftopics.objects.filter(replies = 0)
    return topic_list(request, unanswered_topics, page_message = "Unanswered Topics")

def topic_list(request, queryset, page_message):
    payload = {"new_topic_list": queryset, "page_message": page_message}
    return render_to_response("dinette/new_topics.html", payload, RequestContext(request))

def search(request):
    from haystack.views import SearchView
    search_view = SearchView(template = "dinette/search.html")
    return search_view(request)

@login_required
def subscribeTopic(request, topic_id):
    topic = get_object_or_404(Ftopics, pk=topic_id)
    topic.subscribers.add(request.user)
    next = request.GET.get('next', topic.get_absolute_url())
    return redirect(next)

@login_required
def unsubscribeTopic(request, topic_id):
    topic = get_object_or_404(Ftopics, pk=topic_id)
    topic.subscribers.remove(request.user)
    next = request.GET.get('next', topic.get_absolute_url())
    return redirect(next)

@login_required
def subscribeDigest(request):
    user = get_object_or_404(User, pk=request.user.id)
    profile = user.get_profile()
    profile.is_subscribed_to_digest = True
    profile.save()
    next = request.GET.get('next', user.get_profile().get_absolute_url())
    return redirect(next)

@login_required
def unsubscribeDigest(request):
    user = get_object_or_404(User, pk=request.user.id)
    profile = user.get_profile()
    profile.is_subscribed_to_digest = False
    profile.save()
    next = request.GET.get('next', user.get_profile().get_absolute_url())
    return redirect(next)



from django.conf.urls.defaults import patterns, url

urlpatterns = patterns('',
    url(r'^login/', 'django.contrib.auth.views.login', name='auth_login'),
    url(r'^logout/', 'django.contrib.auth.views.logout', name='auth_logout'),
)



from django.conf.urls.defaults import *
from django.conf import settings

from django.contrib import admin
admin.autodiscover()


urlpatterns = patterns('',
    (r'^forum/', include('dinette.urls')),
    (r'^accounts/', include('accounts.urls')),

    (r'^admin/', include(admin.site.urls)),
)

if settings.DEBUG or getattr(settings, 'SERVE_MEDIA', False):
    urlpatterns += patterns(
        'django.views.static',
        (r'^site_media/(?P<path>.*)$', 'serve', 
            { 
                'document_root': settings.MEDIA_ROOT,
                'show_indexes': True
            }
        ),
    )



# Dinette Settings
import os

TOPIC_PAGE_SIZE = 3

REPLY_PAGE_SIZE = 3

AUTH_PROFILE_MODULE = 'dinette.DinetteUserProfile'

RANKS_NAMES_DATA = ((30, "Member"), (100, "Senior Member"), (300, 'Star'))

DINETTE_LOGIN_TEMPLATE = 'dinette/social_login.html'

LOG_FILE_PATH = "\""+os.path.join(os.path.join(os.path.dirname(os.path.normpath(__file__)),'logs'),"logs.txt")+"\""
LOG_FILE_PATH2 = "\""+os.path.join(os.path.join(os.path.dirname(os.path.normpath(__file__)),'logs2'),"logs2.txt")+"\""

LOG_FILE_NAME =  os.path.join(os.path.dirname(os.path.normpath(__file__)),'logging.conf')

FLOOD_TIME = 1000

HAYSTACK_SITECONF = "dinette.search"

HAYSTACK_SEARCH_ENGINE = 'whoosh'

HAYSTACK_WHOOSH_PATH = os.path.join(os.path.dirname(os.path.normpath(__file__)),'index.db')

SITE_URL = "http://127.0.0.1:8000"



from django.test import TestCase
from django.test import Client
from django.contrib.auth.models import Group, User
from django.core.urlresolvers import reverse

import urlparse

from .. import models
from dinette.models import SuperCategory

class Testmaker(TestCase):
    fixtures = ['test_data']

    def setUp(self):
        self.client = Client()

    def test_index_page(self):
        """Check if the homepage is accessible by all"""
        r = self.client.get(reverse('dinette_category'), {})
        self.assertEqual(r.status_code, 200)

    def test_index_page_visible_super_categories(self):
        sup_category_creator = User.objects.create_user(
                username='test', password='123', email='test@test.com')
        general = Group.objects.create(name='general')
        ordinary = Group.objects.create(name='ordinary')
        special = Group.objects.create(name='special')
        sup_category1 = SuperCategory.objects.create(
                name='super1', posted_by=sup_category_creator)
        sup_category1.accessgroups.add(general)
        sup_category2 = SuperCategory.objects.create(
                name='super2', posted_by=sup_category_creator)
        sup_category2.accessgroups.add(ordinary, special)
        sup_category3 = SuperCategory.objects.create(
                name='super3', posted_by=sup_category_creator)

        r = self.client.get(reverse('dinette_category'), {})
        self.assertContains(r, "super1")
        self.assertNotContains(r, "super2")

        user = User.objects.create_user(
                username='user', password='pass')
        user.groups.add(ordinary)
        self.client.login(username='user', password='pass')
        r = self.client.get(reverse('dinette_category'))
        self.assertContains(r, "super1")
        self.assertContains(r, "super2")
        self.assertNotContains(r, "super3")

    def test_new_topics(self):
        r = self.client.get(reverse('dinette_new_for_user'))
        #check for redirection for guest users
        self.assertEqual(r.status_code,302)
        #check for results in case of loggedin users
        r = self.client.login(username='plaban',password='plaban') #this is in test fixture
        self.assertEqual(r,True)
        r = self.client.get(reverse('dinette_new_for_user'))
        self.assertEqual( len(r.context['new_topic_list']),0) # as there are no entry in the db

    
    def test_dinette_active(self):
        r = self.client.get(reverse('dinette_active'))
        self.assertEqual(r.status_code, 200)

    def test_subscribe_to_digest(self):
        r = self.client.get(reverse('dinette_subscribe_to_digest'))
        self.assertEqual(r.status_code, 302)
        self.assertEqual(r['location'].split("=")[1],
                reverse('dinette_subscribe_to_digest'))

        r = self.client.login(username='plaban',password='plaban') #this is in test fixture
        self.assertEqual(r,True)

        r = self.client.get(reverse('dinette_subscribe_to_digest'))
        self.assertEqual(r.status_code, 302)
        self.assertEqual(urlparse.urlparse(r['location']).path, reverse('dinette_user_profile',
            args=['plaban']))



    def test_unsubscribe_from_digest(self):
        r = self.client.get(reverse('dinette_unsubscribe_from_digest'))
        self.assertEqual(r.status_code, 302)
        self.assertEqual(r['location'].split("=")[1],
                reverse('dinette_unsubscribe_from_digest'))

        r = self.client.login(username='plaban',password='plaban') #this is in test fixture
        self.assertEqual(r,True)

        r = self.client.get(reverse('dinette_subscribe_to_digest'))
        self.assertEqual(r.status_code, 302)
        self.assertEqual(urlparse.urlparse(r['location']).path, reverse('dinette_user_profile',
            args=['plaban']))


    def test_unanswered_topics(self):
        r = self.client.get(reverse('dinette_unanswered'))
        topic =  r.context['new_topic_list'][0]
        self.assertEqual(topic.subject,'Details about the Django design patterns')


    def test_user_profile(self):
        response = self.client.get('/forum/users/plaban')
        user =  response.context['user_profile']
        self.assertEqual(user.email,'plaban.nayak@gmail.com')

    def test_category(self):
        response = self.client.get('/forum/dinette/')
        category =  response.context['category']
        self.assertEqual(category.name,"Dinette")
        self.assertEqual(category.description,"Dinette is the best forum app for Django, Period. You are using it right now.")
        supercategory = category.super_category
        self.assertEqual(supercategory.name,"Python and Django")

    def test_post_topic(self):
        self.client.login(username='plaban', password='plaban')
        response = self.client.post('/forum/post/topic/', 
            {'subject':'python','message':'this is python', 
            'message_markup_type':'plain', 'authenticated':'true',
            'categoryid':'1'})
        response = self.client.get('/forum/active/')
        topic = response.context['new_topic_list'][0]
        self.assertEqual(topic.subject, 'python')

    def test_post_reply(self):
        response = self.client.login(username='plaban',password='plaban')
        response = self.client.post("/forum/post/reply/", {'message':'this is good', 'message_markup_type':'plain',
                                                         'authenticated':'True', 'topicid':'1'})
	self.assertEqual(response.status_code, 200)


    def test_edit_reply(self):
        response = self.client.login(username = "plaban",password = "plaban")
        response = self.client.get("/forum/edit/reply/1")
        self.assertEqual(response.status_code,200)
        reponse = self.client.post("/forum/edit/reply/1",{'message':'this is the edit reply','message_markup_type':'plain'                                                          })
        self.assertEqual(response.status_code,200)
        reply = models.Reply.objects.all()[0]
        self.assertEqual(str(reply),'<p>this is the edit reply</p>')



from django.core.management.base import NoArgsCommand
from django.template.loader import render_to_string
from django.contrib.sites.models import Site
from django.contrib.auth.models import User

from mailer import send_html_mail

import datetime

from dinette.models import Ftopics, Reply, DinetteUserProfile

class Command(NoArgsCommand):
    help = """
           Cron job to send daily updates to subscribed users
           Sample cron usage:
           python manage.py daily_updates
           """
    
    def handle_noargs(self, **options):
        site = Site.objects.get_current()
        subject = "Daily Digest: %s" %( site.name)
        from_address = '%s notifications <admin@%s>' %(site.name, site.domain)
        to_address = User.objects.filter(dinetteuserprofile__is_subscribed_to_digest=True).values_list('email', flat=True)
        
        yesterday = datetime.datetime.now() - datetime.timedelta(1)
        topics = Ftopics.objects.filter(created_on__gt=yesterday)
        replies = Reply.objects.filter(updated_on__gt=yesterday)
        users = DinetteUserProfile.objects.filter(user__date_joined__gt=yesterday)
        active_users = DinetteUserProfile.objects.filter(user__last_login__gt=yesterday)

        if any([topics, replies, users, active_users]):
            variables = {'site': site, 'topics': topics, 'replies': replies, 'users': users, 'active_users': active_users}
            html_message = render_to_string('dinette/email/daily_updates.html', variables)
            send_html_mail(subject, html_message, html_message, from_address, to_address)




# Dinette Settings
import os

TOPIC_PAGE_SIZE = 3
REPLY_PAGE_SIZE = 12
AUTH_PROFILE_MODULE = 'dinette.DinetteUserProfile'
RANKS_NAMES_DATA = ((30, "Member"), (100, "Senior Member"), (300, 'Star'))
DINETTE_LOGIN_TEMPLATE = 'dinette/social_login.html'
LOG_FILE_PATH = "\""+os.path.join(os.path.join(os.path.dirname(os.path.normpath(__file__)),'logs'),"logs.txt")+"\""
LOG_FILE_NAME =  os.path.join(os.path.dirname(os.path.normpath(__file__)),'logging.conf')
FLOOD_TIME = 1000
HAYSTACK_SITECONF = "dinette.search"
HAYSTACK_SEARCH_ENGINE = 'whoosh'
HAYSTACK_WHOOSH_PATH = os.path.join(os.path.dirname(os.path.normpath(__file__)),'index.db')
SITE_URL = "http://127.0.0.1:8000"

# Django-Socialauth settings
LOGIN_REDIRECT_URL = '/forum/'
LOGOUT_REDIRECT_URL = '/forum/'
LOGIN_URL = '/accounts/login/'

OPENID_REDIRECT_NEXT = '/accounts/openid/done/'

OPENID_SREG = {"requred": "nickname, email, fullname",
               "optional":"postcode, country",
               "policy_url": ""}

OPENID_AX = [{"type_uri": "http://axschema.org/contact/email",
              "count": 1,
              "required": True,
              "alias": "email"},
             {"type_uri": "http://axschema.org/schema/fullname",
              "count":1 ,
              "required": False,
              "alias": "fname"}]

OPENID_AX_PROVIDER_MAP = {'Google': {'email': 'http://axschema.org/contact/email',
                                     'firstname': 'http://axschema.org/namePerson/first',
                                     'lastname': 'http://axschema.org/namePerson/last'},
                          'Default': {'email': 'http://axschema.org/contact/email',
                                      'fullname': 'http://axschema.org/namePerson',
                                      'nickname': 'http://axschema.org/namePerson/friendly'}
                          }

#TWITTER_CONSUMER_KEY = ''
#TWITTER_CONSUMER_SECRET = ''

#FACEBOOK_APP_ID = ''
#FACEBOOK_API_KEY = ''
#FACEBOOK_SECRET_KEY = ''

#LINKEDIN_CONSUMER_KEY = ''
#LINKEDIN_CONSUMER_SECRET = ''

AUTHENTICATION_BACKENDS = (
    'django.contrib.auth.backends.ModelBackend',
    'socialauth.auth_backends.OpenIdBackend',
    'socialauth.auth_backends.TwitterBackend',
    'socialauth.auth_backends.FacebookBackend',
    'socialauth.auth_backends.LinkedInBackend',
)

# markup settings
from markupfield.markup import DEFAULT_MARKUP_TYPES

MARKUP_RENDERERS = DEFAULT_MARKUP_TYPES
DEFAULT_MARKUP_TYPE = "plain"



import os
from distutils.core import setup
from setuptools import find_packages

overview = open(os.path.join(os.path.dirname(__file__), 'docs/overview.txt'))
data = overview.read()
overview.close()

setup(
    name='dinette',
    description='Dinette is a forum application in the spirit of PunBB.',
    keywords='django, forum',
    packages=find_packages(exclude=["forum", "forum.*"]),
    include_package_data=True,
    version="1.4e",
    author="Agiliq Solutions",
    author_email="hello@agiliq.com",
    long_description= data,
    classifiers = ['Development Status :: 4 - Beta',
                   'Environment :: Web Environment',
                   'Framework :: Django',
                   'Intended Audience :: Developers',
                   'License :: OSI Approved :: GNU General Public License (GPL)',
                   'Operating System :: OS Independent',
                   'Programming Language :: Python',
                   'Topic :: Internet :: WWW/HTTP',
                   'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
                   'Topic :: Internet :: WWW/HTTP :: WSGI',
                   'Topic :: Software Development :: Libraries :: Application Frameworks',
                   'Topic :: Software Development :: Libraries :: Python Modules',
                   ],
    url="http://www.agiliq.com/",
    license="GPL",
    platforms=["all"],
)



from django.conf.urls.defaults import *
from django.contrib.syndication.views import Feed

from dinette.views import LatestTopicsByCategory,LatestRepliesOfTopic

feeds = {
   'category': LatestTopicsByCategory,
   'topic': LatestRepliesOfTopic
}



urlpatterns = patterns('dinette.views',
    url(r'^$','index_page',name='dinette_category'),
    url(r'^new/$','new_topics',name='dinette_new_for_user'),
    url(r'^active/$','active',name='dinette_active'),
    url(r'^unanswered/$','unanswered',name='dinette_unanswered'),
    
    url(r'^search/$','search',name='dinette_search'),
    
    # user profile page
    url(r'^users/(?P<slug>[\w-]+)$', 'user_profile', name='dinette_user_profile'),

    # subscribe to digest
    url(r'^digest/subscribe/$', 'subscribeDigest', name='dinette_subscribe_to_digest'),
    url(r'^digest/unsubscribe/$', 'unsubscribeDigest', name='dinette_unsubscribe_from_digest'),
    
    url(r'^(?P<categoryslug>[\w-]+)/$','category_details', name='dinette_index'),
    url(r'^(?P<categoryslug>[\w-]+)/page(?P<pageno>\d+)/$','category_details', name='dinette_index2'),
    url(r'^post/topic/$','postTopic', name='dinette_posttopic'),
    url(r'^post/reply/$','postReply', name='dinette_postreply'),
    url(r'^(?P<categoryslug>[\w-]+)/(?P<topic_slug>[\w-]+)/$','topic_detail', name='dinette_topic_detail'),
    url(r'^(?P<categoryslug>[\w-]+)/(?P<topic_slug>[\w-]+)/page(?P<pageno>\d+)/$','topic_detail', name='dinette_reply_detail_paged'),
    
    #moderation views - Hence dont bother with SEF urls
    url(r'^moderate/topic/(?P<topic_id>\d+)/close/$','moderate_topic', {'action':'close'}, name='dinette_moderate_close'),
    url(r'^moderate/topic/(?P<topic_id>\d+)/stickyfy/$','moderate_topic', {'action':'sticky'}, name='dinette_moderate_sticky'),
    url(r'^moderate/topic/(?P<topic_id>\d+)/annoucement/$','moderate_topic', {'action':'announce'}, name='dinette_moderate_announce'),
    url(r'^moderate/topic/(?P<topic_id>\d+)/hide/$','moderate_topic', {'action':'hide'}, name='dinette_moderate_hide'),
    
    # post actions, permitted to OP and mods
    url(r'^delete/reply/(?P<reply_id>\d+)$','deleteReply', name='dinette_deletereply'),
    url(r'^edit/reply/(?P<reply_id>\d+)$','editReply', name='dinette_editreply'),

    # subscribe to topic
    url(r'^subscribe/topic/(?P<topic_id>\d+)', 'subscribeTopic', name='dinette_subscribe_to_topic'),
    url(r'^unsubscribe/topic/(?P<topic_id>\d+)', 'unsubscribeTopic', name='dinette_unsubscribe_from_topic'),
)


urlpatterns += patterns('',
    url(r'^feeds/(?P<url>.*)/$', 'django.contrib.syndication.views.Feed' , {'feed_dict': feeds},name='dinette_feed_url'),
    url(r'^feeds/(?P<url>.*)/$', 'django.contrib.syndication.views.Feed' , {'feed_dict': feeds},name='dinette_topic_url'),
)
